import { LarkServer } from "../../types/larkServer"
import LarkBaseService from "./base"

class LarkSheetService extends LarkBaseService {
  /**
   * 向电子表格中插入行。
   * @param {string} sheetToken - 表格令牌。
   * @param {string} range - 插入数据的范围。
   * @param {string[][]} values - 要插入的值。
   * @returns {Promise<LarkServer.BaseRes>} 返回一个包含响应数据的Promise。
   */
  async insertRows(sheetToken: string, range: string, values: string[][]) {
    const path = `/sheets/v2/spreadsheets/${sheetToken}/values_append?insertDataOption=INSERT_ROWS`
    return this.post<LarkServer.BaseRes>(path, {
      valueRange: {
        range,
        values,
      },
    })
  }

  /**
   * 获取指定范围内的电子表格数据。
   * @param {string} sheetToken - 表格令牌。
   * @param {string} range - 要获取数据的范围。
   * @returns {Promise<LarkServer.SpreadsheetRes>} 返回一个包含响应数据的Promise。
   */
  async getRange(sheetToken: string, range: string) {
    const path = `/sheets/v2/spreadsheets/${sheetToken}/values/${range}?valueRenderOption=ToString`
    return this.get<LarkServer.SpreadsheetRes>(path)
  }
}

export default LarkSheetService
